@@ -237,6 +237,14 @@ def array_in_string(array, value, default=False):
     return default
 
 
+def copy(src, dst=False):
+    copy_list = [src, dst]
+    if dst is False:
+        copy_list = f._parse_copy_data_from_obj(src)
+    for dir in copy_list:
+        mirror(dir['src_path'], dir['dst_path'])
+
+
 def mirror(src, dst, **kwargs):
     '''
         Mirrors a source directory to the destination directory.
